[jbpm-commits] JBoss JBPM SVN: r6827 - in jbpm3/branches/jbpm-3.2-soa: ci and 1 other directory.

do-not-reply at jboss.org do-not-reply at jboss.org
Tue Nov 16 19:41:59 EST 2010


Author: alex.guizar at jboss.com
Date: 2010-11-16 19:41:58 -0500 (Tue, 16 Nov 2010)
New Revision: 6827

Modified:
   jbpm3/branches/jbpm-3.2-soa/
   jbpm3/branches/jbpm-3.2-soa/ci/container.sh
   jbpm3/branches/jbpm-3.2-soa/ci/standalone.sh
   jbpm3/branches/jbpm-3.2-soa/pom.xml
Log:
JBPM-2979 replace jbpm-parent with jboss-parent as the latter declares plugin versions;
parameterize Maven settings file in CI scripts



Property changes on: jbpm3/branches/jbpm-3.2-soa
___________________________________________________________________
Name: svn:ignore
   - target
.settings
settings.xml

   + target
.settings


Modified: jbpm3/branches/jbpm-3.2-soa/ci/container.sh
===================================================================
--- jbpm3/branches/jbpm-3.2-soa/ci/container.sh	2010-11-16 15:34:50 UTC (rev 6826)
+++ jbpm3/branches/jbpm-3.2-soa/ci/container.sh	2010-11-17 00:41:58 UTC (rev 6827)
@@ -5,13 +5,14 @@
 #
 # Exported shell variables required:
 # WORKSPACE      work directory
-# JAVA_HOME      location of java development kit
-# JAVA_15_HOME   required if testing against java 1.4 only
-# DATABASE       db2, hsqldb, mssql, mysql, oracle, postgresql
-# CONTAINER      jboss405, jboss423, jboss501, jboss510
+# JAVA_HOME      JDK location
+# JAVA_15_HOME   JDK 1.5 location; required if JAVA_HOME points to JDK 1.4
+# DATABASE       one of db2, hsqldb, mssql, mysql, oracle, postgresql
+# CONTAINER      one of jboss405, jboss423, jboss501, jboss510
 # MYTESTIP_1     bind address
 # MCAST_ADDR     multicast address
-# SOURCE_REPO    location of jboss distributions
+# SOURCE_REPO    JBoss distributions directory
+# MAVEN_SETTINGS Maven settings file; optional, defaults to ci/settings-qa.xml
 
 # Determine JBoss AS version
 case $CONTAINER in
@@ -50,15 +51,17 @@
 
 # Set up Maven
 export MAVEN_OPTS="-Ddatabase=$DATABASE -Xms16m -Xmx256m"
-# Prevent override of an existing settings.xml file, allowing for local runs
-cp -u ci/settings-qa.xml settings.xml
+[ -z $MAVEN_SETTINGS ] && MAVEN_SETTINGS=ci/settings-qa.xml
 
+# Display Maven version
+mvn -v
+
 # Determine jBPM version
-mvn -V -s settings.xml -Dexpression=project.version help:evaluate > $WORKSPACE/version.txt
+mvn -s $MAVEN_SETTINGS -Dexpression=project.version help:evaluate > $WORKSPACE/version.txt
 JBPM_VERSION=`grep '^3\.' $WORKSPACE/version.txt`
 
 # Build jBPM
-mvn -U -s settings.xml -Pdistro -Djbpm.home=$WORKSPACE/jbpm-$JBPM_VERSION \
+mvn -U -s $MAVEN_SETTINGS -Pdistro -Djbpm.home=$WORKSPACE/jbpm-$JBPM_VERSION \
   -Dcontainer=$CONTAINER -Djboss.home=$JBOSS_HOME -Djboss.server=$JBOSS_SERVER clean install
 if [ $? -ne 0 ]; then
   echo "ERROR: failed to build distro"
@@ -78,7 +81,7 @@
 fi
 
 # Fetch proprietary JDBC drivers
-mvn -s settings.xml -N -DoutputFile=$WORKSPACE/dependencies.txt dependency:resolve
+mvn -s $MAVEN_SETTINGS -N -DoutputFile=$WORKSPACE/dependencies.txt dependency:resolve
 
 # DB2 driver
 if [ "$DATABASE" = "db2" ]; then
@@ -146,8 +149,8 @@
 fi
 
 # Run enterprise test suite
-mvn -f enterprise/pom.xml -s settings.xml -Djboss.bind.address=$MYTESTIP_1 \
-  -Dsurefire.jvm.args="-Xms64m -Xmx256m" integration-test | tee $WORKSPACE/tests.log
+mvn -f enterprise/pom.xml -s $MAVEN_SETTINGS -Djboss.bind.address=$MYTESTIP_1 \
+  -Dsurefire.jvm.args="-Xms64m -Xmx256m" verify | tee $WORKSPACE/tests.log
 
 # Stop JBoss AS
 $JBOSS_HOME/bin/shutdown.sh -s jnp://$MYTESTIP_1:1099 -S

Modified: jbpm3/branches/jbpm-3.2-soa/ci/standalone.sh
===================================================================
--- jbpm3/branches/jbpm-3.2-soa/pom.xml	2010-11-16 15:34:50 UTC (rev 6826)
+++ jbpm3/branches/jbpm-3.2-soa/pom.xml	2010-11-17 00:41:58 UTC (rev 6827)
@@ -20,14 +20,14 @@
   <scm>
     <connection>scm:svn:http://anonsvn.jboss.org/repos/jbpm/jbpm3</connection>
     <developerConnection>scm:svn:https://svn.jboss.org/repos/jbpm/jbpm3</developerConnection>
-    <url>http://fisheye.jboss.org/browse/JbpmSvn/jbpm3</url>
+    <url>http://fisheye.jboss.org/browse/jbpm/jbpm3</url>
   </scm>
 
   <!-- Parent -->
   <parent>
-    <groupId>org.jbpm</groupId>
-    <artifactId>jbpm-parent</artifactId>
-    <version>1.0.4</version>
+    <groupId>org.jboss</groupId>
+    <artifactId>jboss-parent</artifactId>
+    <version>5</version>
   </parent>
 
   <!-- Modules -->
@@ -41,6 +41,10 @@
 
   <!-- Properties -->
   <properties>
+    <maven.compiler.target>1.4</maven.compiler.target>
+    <maven.compiler.source>1.4</maven.compiler.source>
+
+    <!-- Dependencies version -->
     <cargo.version>1.0.3</cargo.version>
 
     <!-- Database Driver Versions  -->
@@ -399,17 +403,9 @@
   <build>
     <plugins>
       <plugin>
-        <artifactId>maven-compiler-plugin</artifactId>
-        <configuration>
-          <source>1.4</source>
-          <target>1.4</target>
-        </configuration>
-      </plugin>
-
-      <plugin>
         <artifactId>maven-javadoc-plugin</artifactId>
         <configuration>
-          <source>1.4</source>
+          <source>${maven.compiler.source}</source>
           <quiet>true</quiet>
         </configuration>
       </plugin>
@@ -446,11 +442,6 @@
         </plugin>
 
         <plugin>
-          <artifactId>maven-assembly-plugin</artifactId>
-          <version>2.2-beta-3</version>
-        </plugin>
-
-        <plugin>
           <groupId>org.jboss.maven.plugins</groupId>
           <artifactId>maven-jdocbook-plugin</artifactId>
           <version>2.1.2</version>



More information about the jbpm-commits mailing list
--- jbpm3/branches/jbpm-3.2-soa/ci/standalone.sh	2010-11-16 15:34:50 UTC (rev 6826)
+++ jbpm3/branches/jbpm-3.2-soa/ci/standalone.sh	2010-11-17 00:41:58 UTC (rev 6827)
@@ -1,12 +1,12 @@
 #!/bin/sh
 #
-# Build the project with Maven and
-# run the standalone test suite 
+# Build the project with Maven and run the standalone test suite 
 #
 # Exported shell variables required:
 # JAVA_HOME      location of java development kit
 # JAVA_15_HOME   required if testing against java 1.4 only
 # DATABASE       db2, hsqldb, mssql, mysql, oracle, postgresql
 
 # Determine Java platform version
 JAVA=$JAVA_HOME/bin/java
@@ -22,10 +22,12 @@
 
 # Set up Maven
 export MAVEN_OPTS="-Ddatabase=$DATABASE -Xms16m -Xmx256m"
-# Prevent override of an existing settings.xml file, allowing for local runs
-cp -u ci/settings-qa.xml settings.xml
+[ -z $MAVEN_SETTINGS ] && MAVEN_SETTINGS=ci/settings-qa.xml
 
+# Display Maven version
+mvn -v
+
 # Run standalone test suite
 export JAVA_HOME=$ORIG_JAVA_HOME
-mvn -V -U -s settings.xml -Dsurefire.jvm.args="-Xms64m -Xmx256m" \
-    -Dmaven.test.failure.ignore=true test
+mvn -U -s $MAVEN_SETTINGS -Dsurefire.jvm.args="-Xms64m -Xmx256m" \
+    -Dmaven.test.failure.ignore=true clean test
@@ -1,12 +1,12 @@
 #
-# Exported shell variables required:
-# JAVA_HOME      location of java development kit
-# JAVA_15_HOME   required if testing against java 1.4 only
-# DATABASE       db2, hsqldb, mssql, mysql, oracle, postgresql
+# Environment variables
+# JAVA_HOME      JDK location
+# JAVA_15_HOME   JDK 1.5 location; required if JAVA_HOME points to JDK 1.4
+# DATABASE       one of db2, hsqldb, mssql, mysql, oracle, postgresql
+# MAVEN_SETTINGS Maven settings file; optional, defaults to ci/settings-qa.xml
 
 # Determine Java platform version

Modified: jbpm3/branches/jbpm-3.2-soa/pom.xml
===================================================================